@@ -1,10 +1,13 @@
 from dbt.adapters.base import AdapterPlugin
 
-from dbt.adapters.firebolt.connections import FireboltCredentials
+from dbt.adapters.firebolt.connections import (
+    FireboltConnectionManager,
+    FireboltCredentials,
+)
 from dbt.adapters.firebolt.impl import FireboltAdapter
 from dbt.include import firebolt
 
-__version__ = '1.1.1'
+__version__ = "1.2.0"
 
 Plugin = AdapterPlugin(
     adapter=FireboltAdapter,
